/*******************(C) COPYRIGHT 2020 Masses-Chip ******************************
* File Name          : M8P634_Touch_M1_Lib_CFG.H
* Author             : MASSES CHIP
* Version            : V2.06
* Date               : 2020/03/30
*********************************************************************************



********************************************************************************/

//================================================================================
#ifndef __M8P634_Touch_M1_Lib_CFG_H__
#define __M8P634_Touch_M1_Lib_CFG_H__

//================================================================================
// 触摸正常模式设定
//================================================================================
// 设置CDC模块1需要检测的通道  0: 该通道按键不检测；1: 该通道按键需检测。
#define    EnTk16   1
#define    EnTk17   0
#define    EnTk18   0 
#define    EnTk19   0 
#define    EnTk20   0
#define    EnTk21   0
#define    EnTk22   0
#define    EnTk23   0
#define    EnTk24   0
#define    EnTk25   0
#define    EnTk26   0
#define    EnTk27   0
#define    EnTk28   0
#define    EnTk29   0
#define    EnTk30   0
#define    EnTk31   0

// 设置确认允许响应的最多按键数量     (1 <= value <= TKLib_M0_OPENED_TK_AMOUNT)
#define TKLib_TOUCH_NUM               1

// 设置触摸消抖次数                   (1 <= value <= 255) 
//                                     消抖时间 = TKLib_Debounce_TIME * aSCAN_TIME
//                                     其中aSCAN_TIME 为 TkSignalHandle 调用间隔时间
#define TKLib_Debounce_TIME           3     

// 设置手指触摸最长有效时间           (0<= value <=15) ; 0: 屏蔽此功能；1: 禁止配置；2~15：时间 = value*长按保护检测基准时基
#define TKLib_LONG_TOUCH_TIME         8

// 设置向上自动校准速度               (1<= value <=7) ; 值越小，校准越快
// 如手指先触摸后上电，一开始不能按，需等待一段时间才能按，若想调节等待时间，可修改此部分
#define TKLib_Up_Calibration_Rate     7

// 设置向下自动校准速度               (1<= value <=7) ; 值越小，校准越快
// 手指慢慢靠近触摸，系统会强制校准保护，若想调节靠近保护时间，可修改此部分
// 若调节此处还不能达到你想要的效果，可修改后面的TKLib_CaliBaseTime 
#define TKLib_Down_Calibration_Rate   7

// 设置CDC时钟分频选择位              0->Fosc/4, 1->Fosc/8, 2->Fosc/16, 3->Fosc/32 ; 一般不需要修改
#define TKLib_M1_TKCKS                1

// 设置手指有效触摸检测次数           (1<= value<=15) ; 一般不需要修改
#define TKLib_EFFECTIVE_TOUCH_TIME    3

// 设置手指无效触摸检测次数           (1<= value<=15) ; 一般不需要修改
#define TKLib_INVALID_TOUCH_TIME      3

// 设置触摸采样滤波等级               (0<= value <=2) ; 一般不需要修改; 0->普通,1->中,2->高
#define TKLib_FILTER_LEVEL            1

// 设置当被响应按键超过允许响应的最多按键数量时，是否需要复位触摸      
// 									                  0->不复位触摸系统, 1->复位触摸系统 ; 一般不需要修改
#define TKLib_Multi_TOUCH_RST         0

// 设置校准基准时基                   (1<= value <=254) ; 可根据时基需求调整
// 校准基准时基  = TKLib_CaliBaseTime * 调用时基，调用时基 Demo code 为0.5ms，可根据时基需求修改
#define TKLib_CaliBaseTime            200

// 设置长按保护检测基准时基           (1<= value <=254) ; 可根据时基需求调整
// 长按保护检测基准时基 = TKLib_LongKeyBaseTime * 校准基准时基，Democode为校准基准时基产生后计数，可根据时基需求修改
#define TKLib_LongKeyBaseTime         40

//================================================================================
// 触摸阈值： 取值需具体应用环境决定，最小9，最大255，值越小越灵敏
#define     TKLib_TK16_F_THRESHOLD   15
#define     TKLib_TK17_F_THRESHOLD   15
#define     TKLib_TK18_F_THRESHOLD   15
#define     TKLib_TK19_F_THRESHOLD   15
#define     TKLib_TK20_F_THRESHOLD   15
#define     TKLib_TK21_F_THRESHOLD   15
#define     TKLib_TK22_F_THRESHOLD   15
#define     TKLib_TK23_F_THRESHOLD   15
#define     TKLib_TK24_F_THRESHOLD   15
#define     TKLib_TK25_F_THRESHOLD   15
#define     TKLib_TK26_F_THRESHOLD   15
#define     TKLib_TK27_F_THRESHOLD   15
#define     TKLib_TK28_F_THRESHOLD   15
#define     TKLib_TK29_F_THRESHOLD   15
#define     TKLib_TK30_F_THRESHOLD   15
#define     TKLib_TK31_F_THRESHOLD   15

//================================================================================
// 触摸省电模式设定，一般运用请关闭此模式
//================================================================================
// 设置触摸低功耗模式是否开启  0: 不使用触摸省电模式；1: 使用触摸省电模式。
#define TKLib_TouchLowerPower    0

// 设置CDC模块1需要检测的通道  0: 该通道按键不检测；1: 该通道按键需检测。
#define TKLPGroup0               1
#define TKLPGroup1               1
#define TKLPGroup2               0
#define TKLPGroup3               0

//================================================================================
// 低功耗下触摸通道分组设置， 数据 = {tk1chsh:tk1chsl}，若触摸按键较多时，建议分组检测
// 分组原则要求需要检测的组通道数应相同，减少不同组之间的检测差异，若实际产品tk16~tk22为开启检测的通道
// 例：若分2组，7/2 = 3余1，则建议4个一组 ,即一组TKLib_M1_TKLPGroup0_MASK = 0x000F; 另一组TKLib_M1_TKLPGroup1_MASK = 0x0078
#define TKLib_M1_TKLPGroup0_MASK    0x0007       
#define TKLib_M1_TKLPGroup1_MASK    0x0038 
#define TKLib_M1_TKLPGroup2_MASK    0x003F
#define TKLib_M1_TKLPGroup3_MASK    0x003F 

//================================================================================
// 触摸阈值： 取值需具体应用环境决定，最小3，最大255，值越小越灵敏
#define TKLib_Sleep_F_THRESHOLD     5      
 
//================================================================================ 
// 触摸低功耗模式下辅助端口是否使能   0：不使用辅助端口；1：使用辅助端口
// 此端口用来调整触摸低功耗模式下触摸检测灵敏度，可接电阻或接电容，具体接法请查看触摸低功耗电路设计参考原理图
// 如每组分配的通道数较多时，低功耗下触摸检测灵敏度会较低，此时可以考虑辅助端口来调节低功耗模式下触摸检测灵敏度
#define TKLPLib_RCOUT_EN            0

// 触摸低功耗模式下，辅助端口选择
#if TKLPLib_RCOUT_EN
	
#define OE_RCOUT    OEC    // 对应端口方向寄存器
#define P_RCOUT     IOC    // 对应端口数据寄存器
#define N_RCOUT     4      // 对应端口编号 
 
#endif

// 以下用户不可修改
//================================================================================
#define TKLib_M1_OPENED_TK_AMOUNT   (EnTk16+EnTk17+EnTk18+EnTk19+EnTk20+EnTk21+EnTk22+EnTk23+EnTk24+EnTk25+EnTk26+EnTk27+EnTk28+EnTk29+EnTk30+EnTk31)
#define TKLib_M1_TK_EN_MASK         ((EnTk16<<0)|(EnTk17<<1)|(EnTk18<<2)|(EnTk19<<3)|(EnTk20<<4)|(EnTk21<<5)|(EnTk22<<6)|(EnTk23<<7)|(EnTk24<<8)|(EnTk25<<9)|(EnTk26<<10)|(EnTk27<<11)|(EnTk28<<12)|(EnTk29<<13)|(EnTk30<<14)|(EnTk31<<15))             
          
//================================================================================
#define TKLib_M1_LP_OPENEDGROUP_AMOUNT   (TKLPGroup0+TKLPGroup1+TKLPGroup2+TKLPGroup3)
#define TKLib_M1_LP_TKLPGROUP_MASK       ((TKLPGroup0<<0)|(TKLPGroup1<<1)|(TKLPGroup2<<2)|(TKLPGroup3<<3))             

//================================================================================

#endif

/*********************************END OF FILE************************************/
                             
